@@ -41,7 +41,54 @@ if (exists(".OpiEnv") && !exists("SimH", where=.OpiEnv))
 #
 # Return NULL if succesful, string error message otherwise  
 ################################################################################
-simH.opiInitialize <- function(type="C", A=NA, B=NA, cap=6, display=NULL, maxStim=10000/pi) {
+#' @rdname opiInitialize
+#' @param type N|G|C for the three Henson params for "SimHenson", "SimHensonRT". Type 'X'
+#'   to specify your own A and B values (eg different dB scale)
+#' @param A parameter A for "SimHenson", "SimHensonRT"
+#' @param B parameter B for "SimHenson", "SimHensonRT"
+#' @param cap dB value for capping stdev form Henson formula for "SimHenson", "SimHensonRT"
+#' @param display Dimensions of plot area (-x,+x,-y,+y) to display stim. No display if NULL.
+#'   For "SimHenson", "SimHensonRT", "SimGaussian", "SimNo", "SimYes"
+#' @param maxStim Maximum stimulus value in cd/m^2 used for db <-> cd/m^2 conversions for
+#'   "SimHenson", "SimHensonRT", "SimGaussian"
+#' @details
+#' \subsection{SimHenson}{
+#'   \code{opiInitialize(type="C", A=NA, B=NA, cap=6, maxStim=10000/pi)}
+#'   
+#'   If the chosen OPI implementation is \code{SimHenson}, then \code{type}
+#'   can be one of: \code{"N"}, for normal patients; \code{"G"}, for POAG
+#'   patients; and \code{"C"}, for a combination. See Table 1 in Henson et al
+#'   (2000).
+#'   
+#'   If \code{type} is \code{"X"} then \code{A} and \code{B} should be
+#'   specified and are used in place of one of the three A/B combinations as in
+#'   Henson et al (2000). \code{cap} is the maximum standard deviation value that
+#'   the simulator will use for the slope/spread of the psychometric function.
+#'   
+#'   If \code{display} is a vector of four numbers \code{c(xlow, xhi, ylow, yhi)},
+#'   then a plot area is created of dimension \code{xlim=range(xlow, xhi)} and
+#'   \code{ylim=range(ylow, yhi)} and each call to \code{opiPresent} will display
+#'   a point on the area. The color of the plot area can be set with
+#'   \code{opiSetBackground}, and the color of the displayed point is determined
+#'   by the stimulus passed to \code{opiPresent}.
+#'   
+#'   \code{maxStim} is the maximum stimuls value in cd/\eqn{\mbox{m}^2}{m^2}.
+#'   This is used in converting cd/\eqn{\mbox{m}^2}{m^2} to dB values, and
+#'   vice versa.
+#' }
+#' @examples
+#' # Set up a simple simulation for white-on-white perimetry
+#' chooseOpi("SimHenson")
+#' if (!is.null(opiInitialize(type="C", cap=6)))
+#'   stop("opiInitialize failed")
+#'
+#' # Set up a simple simulation for white-on-white perimetry
+#' # and display the stimuli in a plot region
+#' chooseOpi("SimHenson")
+#' if (!is.null(opiInitialize(type="C", cap=6)))
+#'   stop("opiInitialize failed")
+simH.opiInitialize <- function(type = "C", A = -0.081, B = 3.27, cap = 6,
+                               display = NA, maxStim = 10000 / pi) {
     if (!is.element(type,c("N","G","C","X"))) {
         msg <- paste("Bad 'type' specified for SimHenson in opiInitialize():",type)
         warning(msg)
@@ -84,13 +131,102 @@ simH.opiInitialize <- function(type="C", A=NA, B=NA, cap=6, display=NULL, maxSti
 #   NULL - succsess
 #   -1   - opiInitialize not called
 ################################################################################
+#' @rdname opiSetBackground
+#' @param col DESCRIPTION for OPI implementations based on simulations
+#' @param gridCol DESCRIPTION for OPI implementation based on simulations
+#' @details
+#' \subsection{SimHenson}{ 
+#'   \code{opiSetBackground(col, gridCol)}
+#'   
+#'   \code{col} is the background color of the plot area used for displaying
+#'   stimuli, and \code{gridCol} the color of the gridlines. Note the plot area
+#'   will only be displayed if \code{opiInitialize} is called with a valid display
+#'   argument.
+#' }
 simH.opiSetBackground <- function(col, gridCol) { 
     return (simDisplay.setBackground(col, gridCol))
 }
 
-################################################################################
-#
-################################################################################
+#' @rdname opiPresent
+#' @param fpr false positive rate for OPI implementation "SimHenson"
+#' @param fnr false negative rate for OPI implementation "SimHenson"
+#' @param tt  SOMETHING for OPI implementation "SimHenson"
+#' @param criteria CRITERIA for OPI implementation "SimHenson"
+#' @param rt_shape response time shape parameter for OPI implementation "SimHenson"
+#' @param rt_rate response time rate parameter  for OPI implementation "SimHenson"
+#' @param rt_scale response time scale parameter for OPI implementation "SimHenson"
+#' @details
+#' \subsection{SimHenson}{
+#'   \code{opiPresent(stim, nextStim=NULL, fpr=0.03, fnr=0.01, tt=30)}
+#'   
+#'   If the chosen OPI implementation is \code{SimHenson}, then the response to a
+#'   stimuli is determined by sampling from a Frequency-of-Seeing (FoS) curve
+#'   (also known as the psychometric function) with formula
+#'   \deqn{\mbox{fpr}+(1-\mbox{fpr}-\mbox{fnr})(1-\mbox{pnorm}(x, \mbox{tt}},
+#'   where \eqn{x}{\code{x}} is the stimulus value in Humphrey dB, and pxVar is
+#'   \deqn{\min\left(\mbox{simH.global.cap}, e^{A\times\mbox{tt}+B}\right).}{\code{min(simH.cap, exp(A*tt + B))}.}
+#'   The ceiling \code{simH.global.cap} is set with the call to
+#'   \code{opiInitialize}, and \code{A} and \code{B} are from Table 1 in Henson
+#'   et al (2000). Which values are used is determined by \code{simH.type} which
+#'   is also set in the call to \code{opiInitialize}.
+#'   
+#'   Note that if the stimulus value is less than zero, then the Henson formula
+#'   is not used. The probability of seeing is \code{fpr}.
+#'   
+#'   \code{opiPresent(stim, nextStim=NULL, fpr=0.03, fnr=0.01, tt=NULL,
+#'                    criteria=0.95, rt_shape=5.3, rt_rate=1.4, rt_scale=0.1)}
+#'
+#'   For determinng seen/not-seen for kinetic, the first location (to a fidelity
+#'   of 0.01 degrees) on the path (it only works for single paths now) where the
+#'   probability of seeing is equal to \code{criteria} is found. If no such
+#'   location exists, then the stimuli is not seen. The probability of seeing at
+#'   each location is determined using a frequency-of-seeing curve defined as a
+#'   cumulative Gaussian with parameters controlled by \code{tt} and
+#'   \code{opiInitialize}. At each location along the path, the mean of the FoS
+#'   is taken from the \code{tt} function, which takes a distance-along-path
+#'   (in degrees) as an argument, and returns a dB value which is the static
+#'   threshold at that distance along the path.
+#'   
+#'   Function \code{tt} can return NA for not thresholds that are always not
+#'   seen. At each location along the path, the standard deviation of the FoS
+#'   is sampled from a Gaussion with mean taken from the formula of Henson et
+#'   al (2000), as parametrised by \code{opiInitialize}, and standard deviation
+#'   0.25.
+#'   
+#'   The location of a false positive response (for the total kinetic path) is
+#'   sampled uniformly from the start of the path to the 'seeing' location, or
+#'   the entire path if the stimuli is not seen.
+#'   
+#'   Note that the false positive rate \code{fpr} and the false negative rate
+#'   \code{fnr} are specified for the whole path, and not for the individual
+#'   static responses along the way.
+#'   
+#'   The actual location returned for a seen response is the location where the
+#'   probability of seeing equals \code{criteria}, plus a response time sampled
+#'   from a Gamma distribution parameterised by \code{rt_shape} and \code{rt_rate}
+#'   and multiplied by \code{rt_scale}.That is:
+#'   \code{rgamma(1, shape=rt_shape, rate=rt_rate) / rt_scale}.
+#' }
+#' @examples
+#' # Stimulus is Size III white-on-white as in the HFA
+#' makeStim <- function(db, n) {
+#'   s <- list(x=9, y=9, level=dbTocd(db, 10000/pi), size=0.43, color="white",
+#'             duration=200, responseWindow=1500)
+#'   class(s) <- "opiStaticStimulus"
+#'   return(s)
+#' }
+#' 
+#' chooseOpi("SimHenson")
+#' if (!is.null(opiInitialize(type="C", cap=6)))
+#'   stop("opiInitialize failed")
+#' 
+#' result <- opiPresent(stim=makeStim(10,0), tt=30, fpr=0.15, fnr=0.01)
+#' 
+#' # Will not work as 'stim' is not named
+#' #result <- opiPresent(makeStim(10,0), tt=30, fpr=0.15, fnr=0.01)
+#' 
+#' if (!is.null(opiClose()))
+#'   warning("opiClose() failed")
 simH.opiPresent <- function(stim, nextStim=NULL, fpr=0.03, fnr=0.01, tt=30,
                             criteria=0.97, rt_shape=5.3, rt_rate=1.4, rt_scale=0.1) {
                             UseMethod("simH.opiPresent") }
